You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@cassandra.apache.org by "Philip Thompson (JIRA)" <ji...@apache.org> on 2014/06/25 21:19:24 UTC
[jira] [Commented] (CASSANDRA-7442) Parallelize unit test runner
[ https://issues.apache.org/jira/browse/CASSANDRA-7442?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=14043943#comment-14043943 ]
Philip Thompson commented on CASSANDRA-7442:
--------------------------------------------
I'm seeing similar improvements in time on Linux (15m to 6m) and Windows (30m to 18m). I had no issues setting -Dtest.runners higher than the number of cores.
> Parallelize unit test runner
> ----------------------------
>
> Key: CASSANDRA-7442
> URL: https://issues.apache.org/jira/browse/CASSANDRA-7442
> Project: Cassandra
> Issue Type: Bug
> Components: Tools
> Reporter: T Jake Luciani
> Assignee: T Jake Luciani
> Priority: Minor
> Labels: qa-resolved
> Fix For: 2.1.0
>
> Attachments: 7442.txt
>
>
> Currently we spend ~15 minutes running unit tests.
> We can parallelize the unit tests by splitting the classes up across processes and using more cores.
> This patch adds a new variable -Dtest.runners=X (default is 1)
> Running with 4 runtime goes from 15min to 6min.
> Beyond 1 runner per core I don't see much of a difference
--
This message was sent by Atlassian JIRA
(v6.2#6252)